@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: cryptohash-conduit
 version: 0.1.1
-id: cryptohash-conduit-0.1.1-d1e5ead421e83b382920526806f6c034
-key: crypt_A5mHXAJY1yPKrnjSRdvu40
+id: cryptohash-conduit-0.1.1-9de27027fde4769c987c6d79fca939a3
+key: crypt_19uM0oKYkbaGntisva4hoT
 license: BSD3
 copyright: Vincent Hanquez <vincent@snarc.org>
 maintainer: vincent@snarc.org
@@ -22,13 +22,13 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-conduit-0.1.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-conduit-0.1.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/cryptohash-conduit-0.1.1
-hs-libraries: HScryptohash-conduit-0.1.1-A5mHXAJY1yPKrnjSRdvu40
+hs-libraries: HScryptohash-conduit-0.1.1-19uM0oKYkbaGntisva4hoT
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     conduit-1.2.6.2-e9736ac2851958c9940f374454cdc4fe
     conduit-extra-1.1.10.1-e4383b2e14cc80179dd5007ca51887df
-    cryptohash-0.11.6-e28406db011dea16e99b7bc1708b91dc
+    cryptohash-0.11.7-d9e0f8e58e69d0717d29fde3802983d0
     resourcet-1.1.7.2-b95e5d14f30eaa21587bc62eeb9aed0c
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
 haddock-interfaces: /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock
